pub struct TempoHeader {
pub general_gas_limit: u64,
pub shared_gas_limit: u64,
pub timestamp_millis_part: u64,
pub inner: Header,
}Expand description
Tempo block header.
Encoded as rlp([general_gas_limit, shared_gas_limit, timestamp_millis_part, inner]) meaning that any new
fields added to the inner header will only affect the first list element.
Fields
general_gas_limit: u64Non-payment gas limit for the block.
Shared gas limit allocated for the subblocks section of the block.
timestamp_millis_part: u64Sub-second (milliseconds) portion of the timestamp.
inner: HeaderInner Ethereum Header.
Implementations
Sourceimpl TempoHeader
impl TempoHeader
Sourcepub const fn bitflag_encoded_bytes() -> usize
pub const fn bitflag_encoded_bytes() -> usize
Used bytes by TempoHeaderFlags
Sourcepub const fn bitflag_unused_bits() -> usize
pub const fn bitflag_unused_bits() -> usize
Unused bits for new fields by TempoHeaderFlags
Sourceimpl TempoHeader
impl TempoHeader
Sourcepub fn timestamp_millis(&self) -> u64
pub fn timestamp_millis(&self) -> u64
Returns the timestamp in milliseconds.